@@ -54,7 +54,7 @@ class SEOContext( BrowserView ):
             "seo_html_comment": self.getSEOProperty( 'qSEO_html_comment', default='' ),
             "meta_keywords": self.getSEOProperty('qSEO_keywords', 'Subject', ()),
             "seo_keywords": self.getSEOProperty('qSEO_keywords', default=()),
-            "seo_canonical": ICanonicalLink(self.context).canonical_link,
+            "seo_canonical": self.getCanonical(),
             # Add test properties
             "has_seo_title": self.context.hasProperty('qSEO_title'),
             "has_seo_robots": self.context.hasProperty('qSEO_robots'),
@@ -136,6 +136,10 @@ class SEOContext( BrowserView ):
                                    'meta_content' : len(name_value) == 2 and name_value[1] or ''})
         return result
 
+    def getCanonical(self):
+        canonical = queryAdapter(self.context, ICanonicalLink)
+        return canonical and canonical.canonical_link or ""
+
 
 class SEOContextPropertiesView( BrowserView ):
     """ This class contains methods that allows to manage seo properties.
@@ -308,3 +312,4 @@ class VisibilityCheckerView( BrowserView ):
         plone = queryMultiAdapter((self, self.request),name="plone_portal_state").portal()
         adapter = ISEOConfigletSchema(plone)
         return bool(self.context.portal_type in adapter.types_seo_enabled)
+
